@@ -68,7 +68,7 @@ hill_func <- function(comm, traits, traits_as_is = FALSE, q = 0, base = exp(1),
         if(!inherits(dij, "dist")) stop("`traits` is not a distance object yet `trait_as_is` is TRUE\n")
     } else {
         # traits is not a distance matrix
-        traits <- traits[trait_sp, ]
+        traits <- traits[trait_sp, , drop = FALSE]
 
         if (ncol(traits) == 1) {
             # only 1 trait
@@ -139,6 +139,8 @@ hill_func <- function(comm, traits, traits_as_is = FALSE, q = 0, base = exp(1),
     comm <- sweep(comm, 1, rowSums(comm, na.rm = TRUE), "/")  # relative abun
 
     dij <- as.matrix(dij)
+    if(all(is.na(dij[upper.tri(dij)])))
+        stop("All pairwise distance is NA, do all species have the same trait values?")
     if (stand_dij)
         dij <- dij/max(dij)
 
