@@ -32,9 +32,9 @@ test_that("functional similarity should be between 0 and 1; q = 2", {
 })
 
 test_that("pairwise similarity", {
-  a = hillR::hill_func_parti_pairwise(comm = dummy$abun, traits = dummy$trait, q = 0)
+  a = hillR::hill_func_parti_pairwise(comm = dummy$abun, traits = dummy$trait, q = 0, .progress = FALSE)
   expect_equal(nrow(a), choose(nrow(dummy$abun), 2))
 
-  a2 = hillR::hill_func_parti_pairwise(comm = dummy$abun, traits = dummy$trait, q = 1)
+  a2 = hillR::hill_func_parti_pairwise(comm = dummy$abun, traits = dummy$trait, q = 1, .progress = FALSE)
   expect_equal(nrow(a2), choose(nrow(dummy$abun), 2))
 })
